BehindCurrentEpochError class
Thrown when the client detects it is behind the current epoch, e.g. during an epoch change. The client should reset cached state and retry.
- Inheritance
-
- Object
- WalrusClientError
- RetryableWalrusClientError
- BehindCurrentEpochError
Constructors
- BehindCurrentEpochError([String message = ''])
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited