EpochStateKind enum

The epoch state of the Walrus staking system.

Corresponds to TS SDK's EpochState enum:

  • EpochChangeSync(u16) — epoch transition in progress
  • EpochChangeDone(u64) — epoch change completed
  • NextParamsSelected(u64) — next params have been selected
Inheritance
Available extensions

Values

epochChangeSync → const EpochStateKind

Epoch transition is in progress. Reads should check whether to use the previous committee for blobs certified before this epoch.

epochChangeDone → const EpochStateKind

Epoch change has completed.

nextParamsSelected → const EpochStateKind

Next epoch parameters have been selected.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EpochStateKind>
A constant List of the values in this enum, in order of their declaration.