InternalServerError class

5xx Internal Server Error.

Inheritance

Constructors

InternalServerError([int statusCode = 500, String message = ''])
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
responseBody → String?
Raw response body, if available.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
HTTP status code from the storage node, or null for connection errors.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited