QuiltBlobHeader class

Header information for a blob within a quilt.

Constructors

QuiltBlobHeader({required String identifier, Map<String, String>? tags, required int blobSize, required int contentOffset})
const

Properties

blobSize → int
final
contentOffset → int
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited