WalrusPackageConfig class

Configuration for a Walrus deployment on a specific Sui network.

Contains the on-chain object IDs needed to interact with Walrus Move contracts (blob registration, certification, storage).

Annotations

Constructors

WalrusPackageConfig({required String systemObjectId, required String stakingPoolId, List<String>? exchangeIds})
const

Properties

exchangeIds List<String>?
Optional exchange object IDs for WAL token exchange.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stakingPoolId String
The staking pool ID of the Walrus package.
final
systemObjectId String
The system object ID of the Walrus package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override