QuiltPatchResult class

A single patch entry in a quilt write result, with its computed patch ID.

Constructors

QuiltPatchResult({required int startIndex, required int endIndex, required String identifier, required Map<String, String> tags, required String patchId})
const

Properties

endIndex int
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
patchId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startIndex int
final
tags Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited