encodeBlob method

EncodedBlob encodeBlob(
  1. Uint8List data,
  2. int numShards
)

Encode a blob into primary and secondary slivers for all shards.

Returns an EncodedBlob containing the blob ID, metadata bytes, root hash, and all slivers indexed by sliver pair index.

Uses the native FFI encoder for canonical output.

Implementation

EncodedBlob encodeBlob(Uint8List data, int numShards) {
  return _encodeBlobFFI(data, numShards);
}