WalrusBlobMetadata class

Metadata returned by WalrusFfiBindings.computeMetadata.

Constructors

WalrusBlobMetadata({required Uint8List blobId, required Uint8List rootHash, required int unencodedLength, required int encodingType})

Properties

blobId Uint8List
32-byte blob ID (Blake2b-256).
final
encodingType int
Encoding type (1 = RS2).
final
hashCode int
The hash code for this object.
no setterinherited
rootHash Uint8List
32-byte Merkle root hash.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unencodedLength int
Original unencoded blob size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited