WalrusEncodingParams class

Encoding parameters returned by WalrusFfiBindings.encodingParams.

Constructors

WalrusEncodingParams({required int primarySymbols, required int secondarySymbols, required int symbolSize, required int primarySliverSize, required int secondarySliverSize})

Properties

hashCode int
The hash code for this object.
no setterinherited
primarySliverSize int
final
primarySymbols int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondarySliverSize int
final
secondarySymbols int
final
symbolSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited