resolvedPath property

String? get resolvedPath

The file path of the loaded native library, or null if not loaded.

Useful for propagating the library path to spawned isolates where static configuration is not inherited.

Implementation

static String? get resolvedPath => _resolvedPath;