WalrusFfiEncodedBlob class

Full encoding result from WalrusFfiBindings.encodeBlob.

Constructors

WalrusFfiEncodedBlob({required WalrusBlobMetadata metadata, required List<Uint8List> primarySlivers, required List<Uint8List> secondarySlivers, required int symbolSize})

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata WalrusBlobMetadata
Blob metadata (blob ID, root hash, etc.).
final
primarySlivers List<Uint8List>
Primary slivers, one per shard (indexed 0..nShards-1).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondarySlivers List<Uint8List>
Secondary slivers, one per shard (indexed 0..nShards-1).
final
symbolSize int
Symbol size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited