WriteBlobFlowUploadOptions class

Options for WriteBlobFlow.upload.

Constructors

WriteBlobFlowUploadOptions({required String digest, Map<String, dynamic>? txResult, String? blobObjectId})
const

Properties

blobObjectId String?
Explicit Blob Sui object ID. When provided, txResult extraction is skipped.
final
digest String
Transaction digest from the signed register transaction.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txResult Map<String, dynamic>?
The full transaction result (with objectChanges / effects) so the flow can extract the Blob object ID. If blobObjectId is provided explicitly this may be omitted.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited