txResult property
The full transaction result (with objectChanges / effects) so the flow can extract the Blob object ID. If blobObjectId is provided explicitly this may be omitted.
Implementation
final Map<String, dynamic>? txResult;
The full transaction result (with objectChanges / effects) so the flow can extract the Blob object ID. If blobObjectId is provided explicitly this may be omitted.
final Map<String, dynamic>? txResult;