WriteFileResult class

Result for a single file in a WriteFilesFlow.

Constructors

WriteFileResult({required String id, required String blobId, required String blobObjectId})
const

Properties

blobId String
The quilt blob ID (URL-safe base64, 32 bytes decoded).
final
blobObjectId String
The blob Sui object ID.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Quilt patch ID for this file (URL-safe base64, 37 bytes decoded).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited