WriteFilesFlowRegisterOptions class

Constructors

WriteFilesFlowRegisterOptions({required int epochs, required String owner, required bool deletable, Map<String, String?>? attributes, String? walCoinObjectId, String? walType, BigInt? storageCost, BigInt? writeCost, int? encodedSize})
const

Properties

attributes Map<String, String?>?
Optional blob attributes (key-value metadata).
final
deletable bool
Whether the blob can be deleted.
final
encodedSize int?
Pre-calculated encoded blob size.
final
epochs int
Number of storage epochs.
final
hashCode int
The hash code for this object.
no setterinherited
owner String
Sui address that will own the blob object.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageCost BigInt?
Pre-calculated storage cost in WAL.
final
walCoinObjectId String?
WAL coin object ID for payment.
final
walType String?
WAL coin type string.
final
writeCost BigInt?
Pre-calculated write cost in WAL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited