WriteQuiltResult class
Result of a quilt write operation.
Constructors
-
WriteQuiltResult({required String blobId, required String blobObjectId, required String certifyDigest, required List<
QuiltPatchResult> patches}) -
const
Properties
- blobId → String
-
final
- blobObjectId → String
-
final
- certifyDigest → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
patches
→ List<
QuiltPatchResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited