BlsProvider class abstract
Interface for BLS12-381 min_pk signature operations.
Implementations must use the standard IETF RFC 9380 DST:
BLS_SIG_BLS12381G2_XMD:SHA-256_SSWU_RO_NUL_
This matches Sui Move's native bls12381_min_pk_verify,
MystenLabs fastcrypto, and the Walrus protocol.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregate(
List< Uint8List> signatures) → Uint8List - Aggregate multiple BLS12-381 min_pk signatures into one.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
Uint8List signature, Uint8List publicKey, Uint8List message) → bool - Verify a single BLS12-381 min_pk signature.
-
verifyAggregate(
List< Uint8List> publicKeys, Uint8List message, Uint8List aggregateSignature) → bool -
Verify an aggregate BLS12-381 min_pk signature where all signers
signed the same
message.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited