DirectWriteOptions class
Options for a direct-mode blob write (no upload relay).
Used when writing slivers directly to storage nodes.
- Annotations
Constructors
Properties
- deletable → bool
-
Whether the blob can be deleted.
final
- epochs → int
-
Number of storage epochs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrency → int
-
Maximum concurrent writes to storage nodes.
final
- nodeTimeout → Duration
-
Maximum time to wait for each storage node response.
final
- owner → String?
-
Sui address that will own the blob object.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited