RegisterBlobOptions class
Options for registering a blob on-chain.
Corresponds to the TS SDK's RegisterBlobOptions.
- Annotations
Constructors
Properties
- blobId → String
-
The Walrus blob ID (URL-safe base64 string, as produced by the encoder).
final
- deletable → bool
-
Whether the blob can be deleted.
final
- epochs → int
-
Number of storage epochs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- owner → String?
-
Sui address to transfer the blob object to.
final
- rootHash → Uint8List
-
Merkle root hash of encoded slivers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Unencoded blob size in bytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited