WriteBlobResult class
Result of a complete write blob operation.
- Annotations
Constructors
- WriteBlobResult({required String blobId, required String blobObjectId, required String certifyDigest})
-
const
Properties
- blobId → String
-
The Walrus blob ID.
final
- blobObjectId → String
-
The Sui object ID of the on-chain Blob object.
final
- certifyDigest → String
-
The transaction digest of the certify transaction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited