getBlobMetadata method

Future<Uint8List> getBlobMetadata({
  1. required String blobId,
  2. int concurrencyLimit = 3,
})

Get blob metadata from storage nodes.

Queries nodes in randomized order, returns the first successful response. Falls back to chunked parallel queries if the first attempt fails. Mirrors the TS SDK's getBlobMetadata().

Implementation

Future<Uint8List> getBlobMetadata({
  required String blobId,
  int concurrencyLimit = 3,
}) async {
  return retryOnPossibleEpochChange(
    () => _internalGetBlobMetadata(
      blobId: blobId,
      concurrencyLimit: concurrencyLimit,
    ),
  );
}