getVerifiedBlobStatus method
Get the verified blob status from multiple storage nodes.
Queries nodes until a quorum of responses is reached, then returns the highest-ranked status that has above-validity weight.
Mirrors the TS SDK's getVerifiedBlobStatus().
Implementation
Future<BlobStatus> getVerifiedBlobStatus({required String blobId}) async {
return retryOnPossibleEpochChange(
() => _internalGetVerifiedBlobStatus(blobId: blobId),
);
}