WriteBlobFlowRegisterOptions class
Options for WriteBlobFlow.register.
Constructors
Properties
-
attributes
→ Map<
String, String?> ? -
Optional blob attributes (key-value metadata).
final
- deletable → bool
-
Whether the blob can be deleted.
final
- encodedSize → int?
-
Pre-calculated encoded blob size.
Required when walCoinObjectId is provided.
final
- epochs → int
-
Number of storage epochs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- owner → String
-
Sui address that will own the blob object.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageCost → BigInt?
-
Pre-calculated storage cost in WAL.
Required when walCoinObjectId is provided.
final
- walCoinObjectId → String?
-
WAL coin object ID for payment. Required for production use.
If null, falls back to legacy gas-coin payment (deprecated).
final
- walType → String?
-
WAL coin type string (e.g.,
0x...::wal::WAL). Required when walCoinObjectId is provided.final - writeCost → BigInt?
-
Pre-calculated write cost in WAL.
Required when walCoinObjectId is provided.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited